==> haskell-email-validate-2.3.2.12-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.12
id: email-validate-2.3.2.12-I2BUPjtawIkFUV6J9ZIdeJ
key: email-validate-2.3.2.12-I2BUPjtawIkFUV6J9ZIdeJ
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: 8a8b9addcb657232a8f57f6b55e0779a
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.5/site-local/email-validate-2.3.2.12
library-dirs: /usr/lib/ghc-8.6.5/site-local/email-validate-2.3.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/email-validate-2.3.2.12
hs-libraries: HSemail-validate-2.3.2.12-I2BUPjtawIkFUV6J9ZIdeJ
depends:
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.12-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.12
id: email-validate-2.3.2.12-C9c9LbIg561AU8JSgYR178
key: email-validate-2.3.2.12-C9c9LbIg561AU8JSgYR178
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: 98a5630ff6fe7ac8aa9cafc2f68a2e62
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.5/site-local/email-validate-2.3.2.12
library-dirs: /usr/lib/ghc-8.6.5/site-local/email-validate-2.3.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/email-validate-2.3.2.12
hs-libraries: HSemail-validate-2.3.2.12-C9c9LbIg561AU8JSgYR178
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
